==> pdf-model-1.14.103-sources.jar: org/verapdf/model/xmplayer/ExtensionSchemaValueType.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.xmplayer;
		
import org.verapdf.model.baselayer.Object;
import java.util.List;

		
/**  Extension schema value type definition
 */
public interface ExtensionSchemaValueType extends ExtensionSchemaObject {
	


	/**  true if type description (’pdfaType:description’ property) is of type Text
	 */
	public Boolean getisDescriptionValidText();

	/**  true if type fields list (’pdfaType:field’ property) is of type Seq
	 */
	public Boolean getisFieldValidSeq();

	/**  true if type namespace URI (’pdfaType:namespaceURI’ property) is of type URI
	 */
	public Boolean getisNamespaceURIValidURI();

	/**  true if type preferred prefix (’pdfaType:prefix’ property) is of type Text
	 */
	public Boolean getisPrefixValidText();

	/**  true if type name (’pdfaType:type’ property) is of type Text
	 */
	public Boolean getisTypeValidText();

	/**  namespace prefix for the description type
	 */
	public String getdescriptionPrefix();

	/**  namespace prefix for the fields list type
	 */
	public String getfieldPrefix();

	/**  namespace prefix for the namespace URI type
	 */
	public String getnamespaceURIPrefix();

	/**  namespace prefix for the prefix type
	 */
	public String getprefixPrefix();

	/**  namespace prefix for the type type
	 */
	public String gettypePrefix();
}

==> pdf-model-1.27.10-sources.jar: org/verapdf/model/xmplayer/ExtensionSchemaValueType.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015-2024, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.xmplayer;
		
import org.verapdf.model.baselayer.Object;
import java.util.Set;

		
/**
* Extension schema value type definition
*/
public interface ExtensionSchemaValueType extends ExtensionSchemaObject {
	


	/**
	* true if type description (’pdfaType:description’ property) is of type Text
	*/
	public Boolean getisDescriptionValidText();

	/**
	* true if type fields list (’pdfaType:field’ property) is of type Seq
	*/
	public Boolean getisFieldValidSeq();

	/**
	* true if type namespace URI (’pdfaType:namespaceURI’ property) is of type URI
	*/
	public Boolean getisNamespaceURIValidURI();

	/**
	* true if type preferred prefix (’pdfaType:prefix’ property) is of type Text
	*/
	public Boolean getisPrefixValidText();

	/**
	* true if type name (’pdfaType:type’ property) is of type Text
	*/
	public Boolean getisTypeValidText();

	/**
	* namespace prefix for the description type
	*/
	public String getdescriptionPrefix();

	/**
	* namespace prefix for the fields list type
	*/
	public String getfieldPrefix();

	/**
	* namespace prefix for the namespace URI type
	*/
	public String getnamespaceURIPrefix();

	/**
	* namespace prefix for the prefix type
	*/
	public String getprefixPrefix();

	/**
	* namespace prefix for the type type
	*/
	public String gettypePrefix();
}
